User Guide
==========

.. grid:: 2
   :gutter: 3

   .. grid-item-card::
      :link: /guide/install
      :link-type: doc
      :link-alt: Installation Guide

      **Installation Guide** :fas:`circle-chevron-right;float-right font-size-1_7em`

   .. grid-item-card::
      :link: /guide/firstrun
      :link-type: doc
      :link-alt: First Run Tutorial

      **New User Tutorial** :fas:`circle-chevron-right;float-right font-size-1_7em`

.. toctree::
   :maxdepth: 2
   :class: multicol-toc

   install
   firstrun
   managing_state
   speed
   migration2